@@ -143,6 +143,9 @@ INVALIDPARAMETERVALUE_IMAGESIZELARGETHANSYSDISKSIZE = 'InvalidParameterValue.Ima
 # 实例配置不匹配。
 INVALIDPARAMETERVALUE_INSTANCECONFIGNOTMATCH = 'InvalidParameterValue.InstanceConfigNotMatch'
 
+# 实例不支持当前操作。
+INVALIDPARAMETERVALUE_INSTANCEIDNOTSUPPORTED = 'InvalidParameterValue.InstanceIdNotSupported'
+
 # 实例名字长度超出限制。
 INVALIDPARAMETERVALUE_INSTANCENAMETOOLONG = 'InvalidParameterValue.InstanceNameTooLong'
 
@@ -242,6 +245,12 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCETYPECONFIGID = 'InvalidParameterValue.Inval
 # 计费类型不合法。
 INVALIDPARAMETERVALUE_INVALIDINTERNETCHARGETYPE = 'InvalidParameterValue.InvalidInternetChargeType'
 
+# 秘钥ID无效。
+INVALIDPARAMETERVALUE_INVALIDKEYPAIRID = 'InvalidParameterValue.InvalidKeyPairId'
+
+# 秘钥名称异常。
+INVALIDPARAMETERVALUE_INVALIDKEYPAIRNAME = 'InvalidParameterValue.InvalidKeyPairName'
+
 # 负载均衡数量不合法。
 INVALIDPARAMETERVALUE_INVALIDLOADBALANCERNUM = 'InvalidParameterValue.InvalidLoadBalancerNum'
 
@@ -368,6 +377,9 @@ LIMITEXCEEDED_ADDRESSQUOTALIMITEXCEEDEDDAILYALLOCATE = 'LimitExceeded.AddressQuo
 # LimitExceeded.AttachedDiskLimitExceeded
 LIMITEXCEEDED_ATTACHEDDISKLIMITEXCEEDED = 'LimitExceeded.AttachedDiskLimitExceeded'
 
+# 分配IPv6网段数量达到上限。
+LIMITEXCEEDED_CIDRBLOCK = 'LimitExceeded.CidrBlock'
+
 # 网卡配额不足。
 LIMITEXCEEDED_ENIQUOTALIMITEXCEEDED = 'LimitExceeded.EniQuotaLimitExceeded'
 
@@ -431,6 +443,9 @@ MISSINGPARAMETER_MISSINGOVERVIEWPARAMETER = 'MissingParameter.MissingOverViewPar
 # 缺少私有IP地址。
 MISSINGPARAMETER_MISSINGPRIVATEIPADDRESS = 'MissingParameter.MissingPrivateIpAddress'
 
+# 不允许执行当前操作。
+OPERATIONDENIED_INSTANCEOPERATIONINPROGRESS = 'OperationDenied.InstanceOperationInProgress'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
